@@ -2,7 +2,7 @@ import re
 from datetime import datetime
 from django.utils.timezone import make_aware
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from rest_framework import serializers
 
 
